-- Accounts Receivables prefix: ar_ systemid: 4
-- Tables for the Accounts Receivables Module
-- Copyright (c) 2001 The Freemoney Project
-- This work is released under the GPL
-- $Id: create_tables_ar.sql,v 1.14 2001/08/05 17:22:43 kaare Exp $

-- Sequences
DROP SEQUENCE ar_arsequence;
DROP SEQUENCE ar_paysequence;

CREATE SEQUENCE ar_arsequence INCREMENT 1;
CREATE SEQUENCE ar_paysequence INCREMENT 1;

--Tables
DROP TABLE ar_contact;
DROP TABLE ar_journal;
DROP TABLE ar_custacct;
DROP TABLE ar_payment;

CREATE TABLE ar_custacct (
       contact_id           integer NOT NULL,
       type                 integer,
       disctype             integer,
       discvalue            decimal,
       updated              timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (contact_id ),
 FOREIGN KEY (type)         REFERENCES sy_typetext,
 FOREIGN KEY (contact_id )  REFERENCES co_contact
  ON DELETE CASCADE
  ON UPDATE CASCADE
);

COMMENT ON TABLE ar_custacct IS 'AR information about the customer.';
COMMENT ON COLUMN ar_custacct.contact_id  IS 'Reference to co_contact table
See also: table!!co_contact.';
COMMENT ON COLUMN ar_custacct.type IS 'Type of AR customer. Values - ??';
COMMENT ON COLUMN ar_custacct.disctype IS 'Discount type. 1 - amount  2 - percent';
COMMENT ON COLUMN ar_custacct.discvalue IS 'Discount value. Depends on disctype';
COMMENT ON COLUMN ar_custacct.updated IS 'Timestamp for last update of this row';

CREATE TABLE ar_contact (
       contact_id           integer NOT NULL,
       periodnr             date NOT NULL,
       sales                decimal,
       paid                 decimal,
       lastdate             date,
       due                  decimal,
       updated              timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (contact_id , periodnr),
 FOREIGN KEY (contact_id )  REFERENCES ar_custacct
  ON DELETE CASCADE
);

COMMENT ON TABLE ar_contact IS 'Totals per month for customer';
COMMENT ON COLUMN ar_contact.contact_id  IS 'Reference to ar_custacct';
COMMENT ON COLUMN ar_contact.periodnr IS 'Period of totals of this customer';
COMMENT ON COLUMN ar_contact.sales IS 'Total sales this period';
COMMENT ON COLUMN ar_contact.paid IS 'Amount paid this period';
COMMENT ON COLUMN ar_contact.lastdate IS '??';
COMMENT ON COLUMN ar_contact.due IS '??';
COMMENT ON COLUMN ar_contact.updated IS 'Timestamp for last update of this row';

CREATE TABLE ar_journal (
       ar_id                integer NOT NULL DEFAULT nextval('ar_arsequence'),
       contact_id           integer,
       periodnr             date,
       invoicenr            integer,
       total                decimal,
       paid                 decimal DEFAULT 0,
       updated              timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (ar_id ),
 FOREIGN KEY (contact_id , periodnr) REFERENCES ar_contact,
 FOREIGN KEY (invoicenr)    REFERENCES so_invoice
  ON UPDATE CASCADE
  ON DELETE CASCADE
);

COMMENT ON TABLE ar_journal IS 'All transactions for the customer';
COMMENT ON COLUMN ar_journal.ar_id  IS 'Sequence number';
COMMENT ON COLUMN ar_journal.contact_id  IS 'Customer reference';
COMMENT ON COLUMN ar_journal.periodnr IS 'Period nr of journal';
COMMENT ON COLUMN ar_journal.invoicenr IS 'Initiating invoice nr. Null if no invoice';
COMMENT ON COLUMN ar_journal.total IS 'Total amount';
COMMENT ON COLUMN ar_journal.paid IS 'Amount already paid';
COMMENT ON COLUMN ar_journal.updated IS 'Timestamp for last update of this row';

CREATE TABLE ar_payment (
       pay_id               integer NOT NULL DEFAULT nextval('ar_paysequence'),
       ar_id                integer,
       contact_id           integer,
       description          varchar(128),
       amount               decimal,
       updated              timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (pay_id ),
 FOREIGN KEY (ar_id )       REFERENCES ar_journal,
 FOREIGN KEY (contact_id )  REFERENCES ar_custacct
);

COMMENT ON TABLE ar_payment IS 'Payments';
COMMENT ON COLUMN ar_payment.pay_id  IS 'Sequence number';
COMMENT ON COLUMN ar_payment.ar_id  IS 'Reference to ar_journal (which invoice is paid)';
COMMENT ON COLUMN ar_payment.contact_id  IS 'Customer';
COMMENT ON COLUMN ar_payment.description IS 'Descriptive text of payment';
COMMENT ON COLUMN ar_payment.amount IS 'Paid amount';
COMMENT ON COLUMN ar_payment.updated IS 'Timestamp for last update of this row';

-- Views

-- Functions

-- Triggers

