-- Subscription prefix: su_ systemid: 10
-- Tables for the Subscription Module
-- Copyright (c) 2001 The FreeMoney event
-- This work is released under the GPL
-- $Id: create_tables_subscription.sql,v 1.3 2001/06/05 08:50:18 kaare Exp $

-- Sequences
DROP SEQUENCE su_event_id;
DROP SEQUENCE su_subscription_id;

CREATE SEQUENCE su_event_id                   INCREMENT 1;
CREATE SEQUENCE su_subscription_id            INCREMENT 1;

--Tables
DROP TABLE su_event;
DROP TABLE su_eventtime;
DROP TABLE su_eventrelease;
DROP TABLE su_subscription;
DROP TABLE su_subscriptarticle;

CREATE TABLE su_event (
       event_id            integer NOT NULL DEFAULT nextval('su_event_id'),
       type               integer,
       updated            timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (event_id )
);

COMMENT ON TABLE su_event IS 'Central event table';
COMMENT ON COLUMN su_event.event_id  IS 'Unique identifier.';
COMMENT ON COLUMN su_event.type IS 'Event type. 1 - time, 2 - new release';
COMMENT ON COLUMN su_event.updated IS 'Time stamp for update.';

CREATE TABLE su_eventtime (
       event_id            integer NOT NULL,
       name               varchar(128),
       intervaltype       integer,
       intervalperiod     integer,
       partial            integer,
       updated            timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (event_id ),
 FOREIGN KEY (event_id ) REFERENCES su_event
);

COMMENT ON TABLE su_eventtime IS 'Time related events';
COMMENT ON COLUMN su_eventtime.event_id  IS 'Reference to su_event';
COMMENT ON COLUMN su_eventtime.name IS 'Name of event';
COMMENT ON COLUMN su_eventtime.intervaltype IS '1 - day, 2 - week, 3 - month, 4 - year';
COMMENT ON COLUMN su_eventtime.intervalperiod IS 'Length of period';
COMMENT ON COLUMN su_eventtime.partial IS 'If there''s partial payment if cancelled in period. 1 - no, 2 - yes';
COMMENT ON COLUMN su_eventtime.updated IS 'Time stamp for update.';

CREATE TABLE su_eventrelease (
       event_id            integer NOT NULL,
       name               varchar(128),
       releasedate        timestamp,
       active             integer,
       updated            timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (event_id ),
 FOREIGN KEY (event_id ) REFERENCES su_event
);

COMMENT ON TABLE su_eventrelease IS 'Release related events';
COMMENT ON COLUMN su_eventrelease.event_id  IS 'Reference to su_event';
COMMENT ON COLUMN su_eventrelease.name IS 'Name of event';
COMMENT ON COLUMN su_eventrelease.releasedate IS 'Date of release';
COMMENT ON COLUMN su_eventrelease.active IS '1 - active, 2 - not active';
COMMENT ON COLUMN su_eventrelease.updated IS 'Time stamp for update.';

CREATE TABLE su_subscription (
       subscription_id     integer NOT NULL DEFAULT nextval('su_subscription_id'),
       contact_id         integer NOT NULL,
       event_id            integer NOT NULL,
       startdate          timestamp NOT NULL,
       nextdate           timestamp,
       invoiced           timestamp,
       enddate            timestamp NOT NULL DEFAULT 'infinity',
       updated            timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (subscription_id ),
 FOREIGN KEY (contact_id ) REFERENCES co_contact,
 FOREIGN KEY (event_id )    REFERENCES su_event
);

COMMENT ON TABLE su_subscription IS 'Subscriptions, linking contact with events';
COMMENT ON COLUMN su_subscription.subscription_id  IS 'Unique identifier.';
COMMENT ON COLUMN su_subscription.contact_id  IS 'Reference to contact';
COMMENT ON COLUMN su_subscription.event_id  IS 'Reference to event';
COMMENT ON COLUMN su_subscription.startdate IS 'Start date for subscription';
COMMENT ON COLUMN su_subscription.nextdate IS 'Next time this subscription will be activated';
COMMENT ON COLUMN su_subscription.invoiced IS 'Latest invoice date';
COMMENT ON COLUMN su_subscription.enddate IS 'Date of cancellation, if any';
COMMENT ON COLUMN su_subscription.updated IS 'Time stamp for update.';

CREATE TABLE su_subscriptarticle (
       subscription_id     integer NOT NULL,
       linenr             integer,
       art_id             integer,
       qty                integer,
       updated            timestamp NOT NULL DEFAULT 'now',
 PRIMARY KEY (subscription_id , linenr),
 FOREIGN KEY (subscription_id ) REFERENCES su_subscription,
 FOREIGN KEY (art_id )          REFERENCES pd_article
);

COMMENT ON TABLE su_subscriptarticle IS 'Subscribed articles';
COMMENT ON COLUMN su_subscriptarticle.subscription_id  IS 'Reference to subscription';
COMMENT ON COLUMN su_subscriptarticle.linenr IS 'Order of articles in subscription';
COMMENT ON COLUMN su_subscriptarticle.art_id  IS 'Reference to article';
COMMENT ON COLUMN su_subscriptarticle.qty IS 'Quantity';
COMMENT ON COLUMN su_subscriptarticle.updated IS 'Time stamp for update.';

-- Views
